shipname = 'Blue Heron'
cruiseid = 'BH19-01_Sharp'
yearbase = 2019
uhdas_dir = '/home/data/BH19-01_Sharp'

# from proc_cfg.py:



## for processing
##----------------
## ship name: shipname = 'Blue Heron'
## at-sea "proc_cfg.py" initialized date = '2017/10/22 16:43:43'
##
## This file starts as /home/adcp/config/proc_cfg.py and
## includes the following information.  Uncomment, left-justify
## and fill these in if you are attempting to generate proc_cfg.py
## from this template.  The file must be named {cruiseid}_proc.py
## or for this example, kk1105_proc.py
##
## example values: fill in for your cruise...
#
# yearbase = 2011                  # usually year of first data logged
# uhdas_dir = '/home/data/kk1105'  # path to uhdas data directory
# shipname = 'Ka`imikai O Kanaloa' # for documentation
# cruiseid = 'kk1105'              # for titles
#
#

#======== serial inputs =========

# choose position instrument (directory and rbin message)

pos_inst = 'gp90'
pos_msg = 'gps'

# choose attitude  instruments (directory and rbin message)

pitch_inst = 'posmv'     # pitch is recorded, but NOT used in transformation
pitch_msg = 'pmv'      # disable with '' (not None)

roll_inst = 'posmv'      # roll is recorded, but NOT used in transformation
roll_msg = 'pmv'       # disable with '' (not None)

hdg_inst = 'gyro'       # reliable heading, used for beam-earth transformation
hdg_msg = 'hdg'


## heading correction
## all heading+msg pairs, for hbin files
hdg_inst_msgs = [
    ('gyro', 'hdg'),
    ('posmv', 'pmv'),
]

## instrument for heading corr to ADCP data (dir and msg)
hcorr_inst = 'posmv'       # disable with '' (not None)
hcorr_msg = 'pmv'        # disable with '' (not None)
hcorr_gap_fill = 0.0   ## fallback correction for hcorr gaps
                     ## calculate hdg_inst - hcorr_inst, eg gyro - ashtech
                     ## SAME SIGN CONVENTION as cal/rotate/ens_hcorr.ang

## if there is a posmv
acc_heading_cutoff = 0.035

# =========== ADCP transformations========
# historically, values were substituted into cruise_proc.m
# now, in Python, they are used directly

# heading alignment:  nominal - (cal/watertrack)
h_align = dict(
     wh300 = 45,
     bb150 = 44.0,
     wh600 = 45,
)

# transducer depth, meters
ducer_depth = dict(
     wh300 = 3,
     bb150 = 3,
     wh600 = 3,
)

# velocity scalefactor
# see SoundspeedFixer in pycurrents/adcp/pingavg.py
scalefactor = dict(
     wh300 = 1.0,
     bb150 = 1.0,
     wh600 = 1.0,
)

# soundspeed
# Soundspeed is usually None, and should ALWAYS be left as None for Ocean Surveyor
# (it is remotely possible that soundspeed for a WH, BB, or NB might need to
#           bet set to a nnumber, but usually that just results in an erroneous
#           scale factor.
soundspeed = dict(
     wh300 = None,
     bb150 = None,
     wh600 = None,
)

# salinity
salinity = dict(
     wh300 = None,
     bb150 = None,
     wh600 = None,
)

#=================================================================
# =========           values for quick_adcp.py          ==========
# ========= These are set here for at-sea procesing,    ==========
# ========= but are REQUIRED in quick_adcp.py control   ==========
# =========  file for batch mode or reprocessing.       ==========

## choose whether or not to use topography for editing
## 0 = "always use amplitude to guess the bottom;
##          flag data below the bottom as bad
## -1 = "never search for the bottom"
## positive integer: Only look for the bottom in deep water
##      "deep water" defined as "topo database says greater than this"

max_search_depth = dict(
     wh300 = 500,
     bb150 = 500,
     wh600 = 500,
)

# special: weakprof_numbins
weakprof_numbins = dict(
     wh300 = None,
     bb150 = None,
     wh600 = None,
)

# set averaging intervals
enslength = dict(
     wh300 = 120,
     bb150 = 180,
     wh600 = 120,
)

# Estimate of offset between ADCP transducer and gps
# this has one value per instrument
# ADCP (dx=starboard, dy=fwd) meters from GPS
# specify integer values for 'xducer_dx' and 'xducer_dy' for each instrument,
#      as from cal/watertrk/guess_xducerxy

xducer_dx = dict(
)
xducer_dy = dict(
)


## if there is a bad beam, create a dictionary modeled after
## enslen (i.e. Sonar-based, not instrument based) and use the
## RDI number (1,2,3,4) to designate the beam to leave out.


